# kancolle


[![pypi](https://img.shields.io/pypi/v/kancolle.svg)](https://pypi.org/project/kancolle/)
[![python](https://img.shields.io/pypi/pyversions/kancolle.svg)](https://pypi.org/project/kancolle/)
[![Build Status](https://github.com/andychucs/kancolle/actions/workflows/dev.yml/badge.svg)](https://github.com/andychucs/kancolle/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/andychucs/kancolle/branch/main/graphs/badge.svg)](https://codecov.io/github/andychucs/kancolle)



for KanColle assistant software


* Documentation: <https://andychucs.github.io/kancolle>
* GitHub: <https://github.com/andychucs/kancolle>
* PyPI: <https://pypi.org/project/kancolle/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
